package com.miaxis.gan.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.miaxis.disease.domain.DiseasePart;
import com.miaxis.gan.domain.GanZhi;
import com.miaxis.gan.dto.GanZhiDto;
import com.miaxis.gan.dto.LiuNianDto;
import com.miaxis.gan.vo.GanZhiDaYunVo;
import com.miaxis.gan.vo.GanZhiKongWangVo;
import com.miaxis.gan.vo.GanZhiNaYinVo;
import com.miaxis.gan.vo.GanZhiRowVo;
import com.nlf.calendar.Lunar;

import java.util.List;
import java.util.Map;

/**
 * 天干地支Service接口
 *
 * @author miaxis
 * @date 2023-11-16
 */
public interface IGanZhiService extends IService<GanZhi>{
    /**
     * 查询天干地支列表
     *
     * @param ganZhi 天干地支
     * @return 天干地支集合
     */
    List<GanZhi> selectGanZhiList(GanZhi ganZhi);

    List<GanZhiRowVo> selectGanZhiRowVoList(GanZhiDto ganZhiDto);

    List<GanZhiNaYinVo> selectGanZhiNaYinList(GanZhiDto ganZhiDto);

    List<GanZhiKongWangVo> selectGanZhiKongWangList(GanZhiDto ganZhiDto);


    /**
     * 日元的强
     * @param ganZhiRowVoList
     * @return
     */
    Map<String,Object> getRiYuanQr(List<GanZhiRowVo> ganZhiRowVoList,Map<String,Integer> fiveCountMap);

    /**
     * 疾病
     * @param ganZhiRowVoList
     * @return
     */
    List<DiseasePart> getJiBing(List<GanZhiRowVo> ganZhiRowVoList, Map<String,Integer> fiveCountMap);

    /**
     * 返回喜用数字
     * @param qr 日元强弱MAP
     * @return
     */
    Map<String, Object> getNumberYun(Map<String, Object> qr);


    /**
     * 获取种五行数量
     * @param ganZhiRowVoList
     * @return
     */
    Map<String,Integer> getGanZhiRowVoCount(List<GanZhiRowVo> ganZhiRowVoList,Map<String,String> reportMap);

    /**
     * 获取十神数量
     * @param ganZhiRowVoList
     * @return
     */
    Map<String, Integer> getShiShenCount(List<GanZhiRowVo> ganZhiRowVoList,Map<String,String> reportMap);

    /**
     * 潮湿平衡
     * @param ganZhiRowVoList
     * @return
     */
    Map<String, Integer> getZaoShiCount(List<GanZhiRowVo> ganZhiRowVoList,Map<String, Integer> fiveCount,Map<String,String> reportMap);


    /**
     * 排大运
     * （阳年男子，大运顺行，阴年男子，大运逆行）
     * （阳年女子，大运逆行，阴年女子，大运顺行）
     * @param ganZhiDto
     * @param ganZhiDaYunVo
     * @return
     */
    GanZhiDaYunVo getDaYun(GanZhiDto ganZhiDto, GanZhiDaYunVo ganZhiDaYunVo);

    /**
     * 根据大运开始查流年
     * @param linNianDto
     * @return
     */
    List<Map<String, String>> getLiuNian(LiuNianDto linNianDto);


    int getMaxTianGan(GanZhiDto ganZhiDto);

    Map<String,String> getGeJu(List<GanZhiRowVo> list, int maxTianGan, String qr);

    Map<Integer, String> getGuo3Guan(List<GanZhiRowVo> list, String qr);

    String getXiFangWei(Lunar lunar);

    String getIndustry(Map<String, Object> riYuanQrMap,String geju);

    String getGuiren(List<GanZhiRowVo> ganZhiRowVoList);

    Map<String, String> getChenGu(Lunar lunar,Integer sex);

    String getBiQi(List<GanZhiRowVo> ganZhiRowVoList);

    String getCaiYun(List<GanZhiRowVo> ganZhiRowVoList, Map<String, Object> riYuanQrMap, Map<String, Integer> shiShenCountMap);
}
